@@ -1,4 +1,3 @@
-
 import threading2
 from threading import *
 from threading import _RLock,_Event,_Condition,_Semaphore,_BoundedSemaphore, \
@@ -351,7 +350,7 @@ class Thread(Thread):
             if self.__priority is not None:
                 self._set_priority(self.__priority)
             if self.__affinity is not None:
-                self._set_priority(self.__affinity)
+                self._set_affinity(self.__affinity)
         @property
         def ident(self):
             return self.__ident
@@ -450,8 +449,8 @@ class SHLock(object):
                 self.is_exclusive -= 1
                 if not self.is_exclusive:
                     self._exclusive_owner = None
-                    #  If there are waiting shared locks, issue them
-                    #  all and them wake everyone up.
+                    #  If there are waiting shared locks, issue it to them
+                    #  all and then wake everyone up.
                     if self._shared_queue:
                         for (thread,waiter) in self._shared_queue:
                             self.is_shared += 1
@@ -504,7 +503,7 @@ class SHLock(object):
             try:
                 self._shared_queue.append((me,waiter))
                 if not waiter.wait(timeout=timeout):
-                    self._shared_queue.remove(waiter)
+                    self._shared_queue.remove((me,waiter))
                     return False
                 assert not self.is_exclusive
             finally:
@@ -529,7 +528,7 @@ class SHLock(object):
             try:
                 self._exclusive_queue.append((me,waiter))
                 if not waiter.wait(timeout=timeout):
-                    self._exclusive_queue.remove(waiter)
+                    self._exclusive_queue.remove((me,waiter))
                     return False
             finally:
                 self._return_waiter(waiter)
@@ -597,8 +596,7 @@ def process_affinity(affinity=None):
     """
     if affinity is not None:
         affinity = CPUSet(affinity)
-        if affinity != system_affinity():
+        if not affinity.issubset(system_affinity()):
             raise ValueError("unknown cpus: %s" % affinity)
     return system_affinity()
 
-
